import { delay } from "@pnp/core";
import { errorCheck, InjectHeaders } from "@pnp/queryable";
import { GraphQueryable, graphGet } from "../graphqueryable.js";
export function PreferAsync(pollIntervalMs = 25000, maxPolls = 4) {
    return (instance) => {
        instance.using(InjectHeaders({ "Prefer": "respond-async" }));
        instance.on.parse(errorCheck);
        instance.on.parse(async function (url, response, result) {
            if (response.status === 202) {
                const opLocation = response.headers.get("Location");
                const opId = opLocation.split("/").at(-1);
                const statusQuery = GraphQueryable(instance, `operations/${opId}`);
                for (let i = 0; i < maxPolls; i++) {
                    await delay(pollIntervalMs);
                    const status = await statusQuery();
                    if (status.status === "succeeded") {
                        const resultEndpoint = status.resourceLocation.split("/").at(-1);
                        result = await graphGet(GraphQueryable(instance, resultEndpoint));
                    }
                    else if (status.status === "failed") {
                        throw status.error;
                    }
                }
                throw new Error(`Timed out waiting for async operation after ${pollIntervalMs * maxPolls}ms`);
            }
            return [url, response, result];
        });
        return instance;
    };
}
//# sourceMappingURL=prefer-async.js.map