import { addProp, body } from "@pnp/queryable";
import { graphGet, graphPost } from "../graphqueryable.js";
import { Site, _Site } from "../sites/types.js";
import { ContentTypes, _ContentTypes } from "./types.js";
/**
     * Create a new  content type as specified in the request body.
     *
     * @param contentType  a JSON representation of a ContentType object.
     */
_ContentTypes.prototype.add = async function (contentType) {
    const data = await graphPost(this, body(contentType));
    return {
        data,
        contentType: this.getById(data.id),
    };
};
/**
     * Associate a published content type present in a content type hub with a list of hub sites.
     * NOTE: the site MUST be the content type hub
     * @param hubSiteUrls  an array of hub site urls to associate the content type with.
     * @param propagateToExistingLists (Optional: Default False) If true, content types will be enforced on existing lists in the hub sites;
     *   otherwise, it'll be applied only to newly created lists.
     */
_ContentTypes.prototype.associateWithHubSites = function associateWithHubSites(hubSiteUrls, propagateToExistingLists = false) {
    const postBody = {
        hubSiteUrls,
        propagateToExistingLists,
    };
    return graphPost(Site(this, "associateWithHubSites"), body(postBody));
};
addProp(_Site, "contentTypes", ContentTypes);
/**
 * Get site contentTypes that can be added to a list.
 */
_Site.prototype.getApplicableContentTypesForList = function getApplicableContentTypesForList(listId) {
    return graphGet(Site(this, `getApplicableContentTypesForList(listId='${listId}')`));
};
//# sourceMappingURL=sites.js.map