import { __decorate } from "tslib";
import { body } from "@pnp/queryable";
import { _GraphCollection, _GraphInstance, graphInvokableFactory, graphDelete, graphPost } from "../graphqueryable.js";
import { defaultPath, getById } from "../decorators.js";
/**
 * Member
 */
export class _Member extends _GraphInstance {
    /**
     * Removes this Member
     */
    remove() {
        return graphDelete(Member(this, "$ref"));
    }
}
export const Member = graphInvokableFactory(_Member);
/**
 * Members
 */
let _Members = class _Members extends _GraphCollection {
    /**
     * Use this API to add a member to an Office 365 group, a security group or a mail-enabled security group through
     * the members navigation property. You can add users or other groups.
     * Important: You can add only users to Office 365 groups.
     *
     * @param id Full @odata.id of the directoryObject, user, or group object you want to add (ex: `https://graph.microsoft.com/v1.0/directoryObjects/${id}`)
     */
    add(id) {
        return graphPost(Members(this, "$ref"), body({ "@odata.id": id }));
    }
};
_Members = __decorate([
    defaultPath("members"),
    getById(Member)
], _Members);
export { _Members };
export const Members = graphInvokableFactory(_Members);
//# sourceMappingURL=types.js.map